# GARB - Google Analytics Request Builder

GARB is a small library that provides a comfortable way of building a Request
Body for Google Analytics Reporting API v4.

## Installation

### Using pip

Install `garb` using [pip](https://pip.pypa.io/en/stable/quickstart/):

    pip install garb

### From Source

Alternatively, you can install `garb` from source:

    git clone https://github.com/czuhajster/garb


## License

GARB is licensed under [MIT License](https://github.com/czuhajster/garb/blob/main/LICENSE.md).
